Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewK8sClient ¶
NewK8sClient discover if kubeconfig creds are inside a Pod or outside the cluster and return a clientSet
Types ¶
type K8sClient ¶
type K8sClient interface {
DeletePod(ctx context.Context, pod, namespace string) error
GenerateToBeDeletedPodList(ctx context.Context, namespace, eventReason, errorMessage string, counter, pollingInterval int) (map[string]string, error)
PodChecks(ctx context.Context, podName, podNamespace string) error
}
type PodDetails ¶
type PodDetails struct {
UID types.UID
PodName string
PodNamespace string
ResourceVersion string
OwnerReferences []metav1.OwnerReference
Phase v1.PodPhase
ContainerStatuses []v1.ContainerStatus
CreationTimestamp time.Time
DeletionTimestamp *metav1.Time
}
PodDetails holds data associated with a Pod
Click to show internal directories.
Click to hide internal directories.